#[repr(transparent)]pub struct FixedSelection {
inner: TypedObjectRef<FixedSelection, ()>,
phantom: PhantomData<()>,
}Expand description
A GtkSelectionModel that keeps track of the selected item even if its
position changes or it is removed from the list.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<FixedSelection, ()>phantom: PhantomData<()>Implementations
Sourceimpl FixedSelection
impl FixedSelection
Sourcepub fn set_model<'a>(
&self,
value: Option<impl Borrow<<<BoundObject<ListModel> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_model<'a>( &self, value: Option<impl Borrow<<<BoundObject<ListModel> as Property>::Value as HasParamSpec>::SetValue>>, )
The underlying model.
Sourcepub fn set_selected<'a>(
&self,
value: impl Borrow<<<Cell<u32> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_selected<'a>( &self, value: impl Borrow<<<Cell<u32> as Property>::Value as HasParamSpec>::SetValue>, )
The position of the selected item.
Sourcepub fn set_selected_item<'a>(
&self,
value: Option<impl Borrow<<<RefCell<Option<Object>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_selected_item<'a>( &self, value: Option<impl Borrow<<<RefCell<Option<Object>> as Property>::Value as HasParamSpec>::SetValue>>, )
The selected item.
Sourcepub fn connect_model_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the model property
Sourcepub fn connect_selected_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_selected_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the selected property
Sourcepub fn connect_selected_item_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_selected_item_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the selected-item property
Sourcepub fn connect_is_empty_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_empty_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-empty property
Sourcepub fn notify_model(&self)
pub fn notify_model(&self)
Notify listeners of a change in the model property
Sourcepub fn notify_selected(&self)
pub fn notify_selected(&self)
Notify listeners of a change in the selected property
Sourcepub fn notify_selected_item(&self)
pub fn notify_selected_item(&self)
Notify listeners of a change in the selected-item property
Sourcepub fn notify_is_empty(&self)
pub fn notify_is_empty(&self)
Notify listeners of a change in the is-empty property
Sourceimpl FixedSelection
impl FixedSelection
Sourcepub fn new(model: Option<&impl IsA<ListModel>>) -> Self
pub fn new(model: Option<&impl IsA<ListModel>>) -> Self
Construct a new FixedSelection with the given model.
Sourcepub(crate) fn set_item_equivalence_fn(
&self,
equivalence_fn: impl Fn(&Object, &Object) -> bool + 'static,
)
pub(crate) fn set_item_equivalence_fn( &self, equivalence_fn: impl Fn(&Object, &Object) -> bool + 'static, )
Set the function to use to test for equivalence of two items.
It is used when checking if an object still present when the underlying model changes. Which means that if there are two equivalent objects at the same time in the underlying model, the selected item might change unexpectedly between those two objects.
If this is not set, the Eq implementation is used, meaning that they
must be the same object.